@@ -88,6 +88,22 @@ const std::set<const Tensor*> SubgraphImp::get_input_tensors() const {
   return ret;
 }
 
+std::vector<Tensor*> SubgraphImp::get_sorted_input_tensors(
+    const std::function<bool(Tensor*, Tensor*)>& compare) {
+  return internal::cast_from_const_vector(
+      static_cast<const SubgraphImp&>(*this).get_sorted_input_tensors(compare));
+}
+
+const std::vector<const Tensor*> SubgraphImp::get_sorted_input_tensors(
+    const std::function<bool(Tensor*, Tensor*)>& compare) const {
+  auto ret = std::vector<Tensor*>();
+  auto ret_s = internal::cast_from_const_set(
+      static_cast<const SubgraphImp&>(*this).get_input_tensors());
+  ret.assign(ret_s.begin(), ret_s.end());
+  sort(ret.begin(), ret.end(), compare);
+  return internal::cast_to_const_vector(ret);
+}
+
 std::set<Tensor*> SubgraphImp::get_output_tensors() {
   return internal::cast_from_const_set(
       static_cast<const SubgraphImp&>(*this).get_output_tensors());
@@ -110,6 +126,23 @@ const std::set<const Tensor*> SubgraphImp::get_output_tensors() const {
   return ret;
 }
 
+std::vector<Tensor*> SubgraphImp::get_sorted_output_tensors(
+    const std::function<bool(Tensor*, Tensor*)>& compare) {
+  return internal::cast_from_const_vector(
+      static_cast<const SubgraphImp&>(*this).get_sorted_output_tensors(
+          compare));
+}
+
+const std::vector<const Tensor*> SubgraphImp::get_sorted_output_tensors(
+    const std::function<bool(Tensor*, Tensor*)>& compare) const {
+  auto ret = std::vector<Tensor*>();
+  auto ret_s = internal::cast_from_const_set(
+      static_cast<const SubgraphImp&>(*this).get_output_tensors());
+  ret.assign(ret_s.begin(), ret_s.end());
+  sort(ret.begin(), ret.end(), compare);
+  return internal::cast_to_const_vector(ret);
+}
+
 std::int32_t SubgraphImp::count_op_(
     const std::set<std::string>& op_types) const {
   std::int32_t ret = 0;
@@ -722,51 +755,4 @@ std::vector<std::map<OpTemplate*, Op*>> SubgraphImp::isomorphism(
 
   return *result;
 }
-
 }  // namespace xir
-
-/* C API implementations */
-#include "xir/xir.h"
-namespace xir {
-class c_api {
- public:
-  static const char* subgraph_get_name(xir_subgraph_t subgraph) {
-    auto self = static_cast<xir::SubgraphImp*>(subgraph);
-    return self->name_.c_str();
-  }
-  static xir_subgraph_t subgraph_get_child(xir_subgraph_t subgraph,
-                                           int32_t idx) {
-    auto self = static_cast<xir::SubgraphImp*>(subgraph);
-    auto child = self->children_.begin();
-    for (int i = 0; i < idx; i++) {
-      child++;
-    }
-    return static_cast<xir_subgraph_t>((*child).get());
-  }
-
-  static void subgraph_children_topological_sort(xir_subgraph_t subgraph,
-                                                 xir_subgraph_t children[]) {
-    auto self = static_cast<xir::SubgraphImp*>(subgraph);
-    auto ret = self->children_topological_sort();
-    int i = 0;
-    for (auto child : ret) {
-      children[i++] = static_cast<xir_subgraph_t>(child);
-    }
-  }
-};
-};  // namespace xir
-extern "C" const char* xir_subgraph_get_name(xir_subgraph_t subgraph) {
-  return xir::c_api::subgraph_get_name(subgraph);
-}
-extern "C" int32_t xir_subgraph_get_children_num(xir_subgraph_t subgraph) {
-  return static_cast<xir::Subgraph*>(subgraph)->get_children_num();
-}
-extern "C" xir_subgraph_t xir_subgraph_get_child(xir_subgraph_t subgraph,
-                                                 int32_t idx) {
-  return xir::c_api::subgraph_get_child(subgraph, idx);
-}
-
-extern "C" void xir_subgraph_children_topological_sort(
-    xir_subgraph_t subgraph, xir_subgraph_t children[]) {
-  return xir::c_api::subgraph_children_topological_sort(subgraph, children);
-}
